@@ -22,22 +22,10 @@ DatabionicSwarmClustering=function(DataOrDistances,ClusterNo=0,StructureType=TRU
   # Object            List of further output of DBS.
   #
   # Author: MT
-  if (!requireNamespace('DatabionicSwarm',quietly = TRUE)){
-    message(
-      'Subordinate clustering package (DatabionicSwarm) is missing. No computations are performed.
-            Please install the package which is defined in "Suggests".'
-    )
-    return(
-      list(
-        Cls = rep(1, nrow(DataOrDistances)),
-        Object = "Subordinate clustering package (DatabionicSwarm) is missing.
-                Please install the package which is defined in 'Suggests'."
-      )
-    )
-  }
   
   if(StructureType==1) StructureType=TRUE
   if(StructureType==0) StructureType=FALSE
+  
   if(missing(DataOrDistances)){
     DataOrDistances=Data
   }
@@ -47,6 +35,22 @@ DatabionicSwarmClustering=function(DataOrDistances,ClusterNo=0,StructureType=TRU
   }
   generalizedUmatrix=NULL # Init in case of no plotting
   DataPoints=NULL  # Init in case of no plotting
+  Cls = rep(1, nrow(DataOrDistances))#init
+  
+  if (!requireNamespace('DatabionicSwarm',quietly = TRUE)){
+    message(
+      'Subordinate clustering package (DatabionicSwarm) is missing. No computations are performed.
+            Please install the package which is defined in "Suggests".'
+    )
+    return(
+      list(
+        Cls = Cls,
+        Object = "Subordinate clustering package (DatabionicSwarm) is missing.
+                Please install the package which is defined in 'Suggests'."
+      )
+    )
+  }
+
   message("Operator: Computing nonlinear projection using the swarm.")
   if(is.null(DistancesMethod)){
     if (isSymmetric(unname(DataOrDistances))) {
@@ -58,41 +62,49 @@ DatabionicSwarmClustering=function(DataOrDistances,ClusterNo=0,StructureType=TRU
       }
       else{
         stop('ProjectionBasedClustering package not loaded or installed.')
-      }
+      }#end requireNamespace("ProjectionBasedClustering)
       
     }else{
       DataPoints=DataOrDistances
-    }
+    }#end isSymmetric(unname(DataOrDistances)
     if(requireNamespace("DatabionicSwarm",quietly = TRUE)){
       proj= DatabionicSwarm::Pswarm(DataOrDistance = DataOrDistances)
     }
     else{
       stop('DatabionicSwarm package not loaded or installed.')
-    }
+    }# end requireNamespace("DatabionicSwarm"
     
   }else{
     requireNamespace('parallelDist')
     DataDists=as.matrix(parallelDist::parallelDist(DataOrDistances,method = DistancesMethod))
     proj= DatabionicSwarm::Pswarm(DataOrDistance = DataDists)
-  }
+  }#end is.null(DistancesMethod)
 
   if(ClusterNo==0){
-    if(PlotTree){
+    if(isTRUE(PlotTree)){
       message("Operator: Generating dendrogram.")
       Cls=DatabionicSwarm::DBSclustering(1,DataOrDistance = DataOrDistances,BestMatches =TwoD_Points,LC = LC,
                                          StructureType = StructureType,PlotIt = PlotTree)
-    }
+    }#end isTRUE(PlotTree
     if(!is.null(DistancesMethod))    
       DataPoints=ProjectionBasedClustering::MDS(DataDists,OutputDimension = nrow(DataDists))$ProjectedPoints
-   
-   message("Operator: Generating topograhpic map of high-dimensional structures.")
-   generalizedUmatrix=DatabionicSwarm::GeneratePswarmVisualization(Data = DataPoints,ProjectedPoints = proj$ProjectedPoints,LC = proj$LC)
-   GeneralizedUmatrix::plotTopographicMap(generalizedUmatrix$Umatrix,generalizedUmatrix$Bestmatches)
-   
-  }else{
+    
+    generalizedUmatrix=DatabionicSwarm::GeneratePswarmVisualization(Data = DataPoints,ProjectedPoints = proj$ProjectedPoints,LC = proj$LC)
+    
+    if (requireNamespace('GeneralizedUmatrix',quietly = TRUE)){
+      message("Operator: Generating topographic map of high-dimensional structures.")
+      GeneralizedUmatrix::TopviewTopographicMap(GeneralizedUmatrix = generalizedUmatrix$Umatrix,BestMatchingUnits = generalizedUmatrix$Bestmatches)
+    }else{
+      message(
+        'Subordinate clustering package (GeneralizedUmatrix) is missing. No computations are performed.
+            Please install the package which is defined in "Suggests".Setting "PlotMap=FALSE"'
+      )
+      PlotMap=FALSE
+    }#end requireNamespace('GeneralizedUmatrix'
+  }else{#ClusterNo!=0
     message("Operator: Clustering the dataset.")
     TwoD_Points=proj$ProjectedPoints
-    # Make sure that grid dimensions are correct, even if generalizedUmatrix is not computed which is not necessary for clustering.
+    # Make sure that grid dimensions are correct, even if GeneralizedUmatrix is not computed which is not necessary for clustering.
     LC=c()
     LC[1]=ceiling(max(TwoD_Points[, 1])+1)
     LC[2]=ceiling(max(TwoD_Points[, 2])+1)
@@ -103,20 +115,35 @@ DatabionicSwarmClustering=function(DataOrDistances,ClusterNo=0,StructureType=TRU
     }else{
       Cls=DatabionicSwarm::DBSclustering(ClusterNo,DataOrDistance = DataDists,BestMatches =TwoD_Points,LC = LC,
                         StructureType = StructureType,PlotIt = PlotTree)
-    }
+    }#end is.null(DistancesMethod))
     Cls=ClusterRename(Cls,DataOrDistances)
-  }
-  if(PlotMap){
-    if(ClusterNo!=0){
+  }# end ClusterNo==0
+  if (isTRUE(PlotMap)) {
+    if (ClusterNo != 0) {
       message("Operator: Generating topographic map of high-dimensional structures.")
-      generalizedUmatrix=DatabionicSwarm::GeneratePswarmVisualization(Data = DataPoints,ProjectedPoints = proj$ProjectedPoints,LC = proj$LC)
-    }#otherwise it already exists
-    if(ClusterNo==0){#plotting is already performed in order to derive the number of clusters
+      generalizedUmatrix = DatabionicSwarm::GeneratePswarmVisualization(
+        Data = DataPoints,
+        ProjectedPoints = proj$ProjectedPoints,
+        LC = proj$LC
+      )
+    }#end ClusterNo != 0 #otherwise it already exists
+    if (ClusterNo == 0) {
+      #plotting is already performed in order to derive the number of clusters
       #GeneralizedUmatrix::plotTopographicMap(generalizedUmatrix$Umatrix,generalizedUmatrix$Bestmatches)
-    }else{
-      GeneralizedUmatrix::plotTopographicMap(generalizedUmatrix$Umatrix,generalizedUmatrix$Bestmatches,Cls = Cls)
-    } 
-  }
+    } else{
+      if (requireNamespace('GeneralizedUmatrix', quietly = TRUE)) {
+        GeneralizedUmatrix::plotTopographicMap(generalizedUmatrix$Umatrix,
+                                               generalizedUmatrix$Bestmatches,
+                                               Cls = Cls)
+      }else{
+        message(
+          'Subordinate clustering package (GeneralizedUmatrix) is missing. No computations are performed.
+            Please install the package which is defined in "Suggests".Setting "PlotMap=FALSE"'
+        )
+        PlotMap=FALSE
+      }#end !requireNamespace('GeneralizedUmatrix',
+    }# end ClusterNo == 0)
+  }#end PlotMap
   if(PlotIt){
 	  ClusterPlotMDS(DataOrDistances,Cls)
   }
